==> activity-center-api-0.9.5.1-zbq-20190318.081832-5-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/commercial/dig/DigUserDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.commercial.dig;

import java.io.Serializable;
import java.util.Date;

public class DigUserDto implements Serializable {
    private static final long serialVersionUID = -1371547943056558753L;

    private Long id;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 现金
     */
    private Long cash;

    /**
     * 签到天数
     */
    private Integer signDays;

    /**
     * 上次签到时间
     */
    private Date lastSignTime;


    /**
     * 提现次数
     */
    private Integer withdrawTimes;

    //当前所在层节点数量
    private Integer conditionAmount;

    //当前所在层位置
    private Integer index;



    private Long userId;

    private Long appId;

    private Integer curDigTimes;

    private Integer curOpenTreasureBoxs;

    //当前所在层
    private Integer curLayer;

    private Date lastDigTime;

    private Long restTime;

    private Integer digTimes;

    private String treasureList;

    private String finishedMission;

    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Date getLastDigTime() {
        return lastDigTime;
    }

    public void setLastDigTime(Date lastDigTime) {
        this.lastDigTime = lastDigTime;
    }

    public Long getRestTime() {
        return restTime;
    }

    public void setRestTime(Long restTime) {
        this.restTime = restTime;
    }

    public Integer getDigTimes() {
        return digTimes;
    }

    public void setDigTimes(Integer digTimes) {
        this.digTimes = digTimes;
    }

    public String getFinishedMission() {
        return finishedMission;
    }

    public void setFinishedMission(String finishedMission) {
        this.finishedMission = finishedMission;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getCurDigTimes() {
        return curDigTimes;
    }

    public void setCurDigTimes(Integer curDigTimes) {
        this.curDigTimes = curDigTimes;
    }

    public Integer getCurOpenTreasureBoxs() {
        return curOpenTreasureBoxs;
    }

    public void setCurOpenTreasureBoxs(Integer curOpenTreasureBoxs) {
        this.curOpenTreasureBoxs = curOpenTreasureBoxs;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getCash() {
        return cash;
    }

    public void setCash(Long cash) {
        this.cash = cash;
    }

    public Integer getSignDays() {
        return signDays;
    }

    public void setSignDays(Integer signDays) {
        this.signDays = signDays;
    }

    public Date getLastSignTime() {
        return lastSignTime;
    }

    public void setLastSignTime(Date lastSignTime) {
        this.lastSignTime = lastSignTime;
    }

    public Integer getWithdrawTimes() {
        return withdrawTimes;
    }

    public void setWithdrawTimes(Integer withdrawTimes) {
        this.withdrawTimes = withdrawTimes;
    }

    public String getTreasureList() {
        return treasureList;
    }

    public void setTreasureList(String treasureList) {
        this.treasureList = treasureList;
    }

    public Integer getCurLayer() {
        return curLayer;
    }

    public void setCurLayer(Integer curLayer) {
        this.curLayer = curLayer;
    }

    public Integer getConditionAmount() {
        return conditionAmount;
    }

    public void setConditionAmount(Integer conditionAmount) {
        this.conditionAmount = conditionAmount;
    }

    public Integer getIndex() {
        return index;
    }

    public void setIndex(Integer index) {
        this.index = index;
    }
}

==> activity-center-api-0.9.5.9-zbq-20190422.062715-32-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/commercial/dig/DigUserDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.commercial.dig;

import cn.com.duiba.tuia.activity.center.api.dto.commercial.common.StageDto;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class DigUserDto implements Serializable {
    private static final long serialVersionUID = -1371547943056558753L;

    private Long id;

    /**
     * 设备ID
     */
    private String deviceId;

    /**
     * 现金
     */
    private Long cash;

    /**
     * 签到天数
     */
    private Integer signDays;

    /**
     * 上次签到时间
     */
    private Date lastSignTime;


    /**
     * 图件信息
     */
    private List<Integer> illustratedHandbookInfo;

    /**
     * 宝藏列表
     */
    private List<ArrayList<Integer>> treasureList;


    /**
     * 提现次数
     */
    private Integer withdrawTimes;


    /**
     * 当天所在周期
     */
    private Integer stage;

    /**
     * 周期总数
     */
    private Integer stageAmount;

    /**
     * 提现门槛
     */
    private Long withdrawThreshold;

    /**
     * 提现周期配置
     */
    private List<StageDto> stages;

    //当前所在层节点数量
    private Integer conditionAmount;

    //当前所在层位置
    private Integer curLayerIndex;

    private Integer conditionAmountSum;

    private Integer bizActivityType;


    private Long userId;

    private Long appId;

    private Integer curDigTimes;

    private Integer curOpenTreasureBoxs;

    //当前所在层
    private Integer curLayer;

    private Date lastDigTime;

    private Long restTime;

    private Integer digTimes;


    private Date gmtCreate;

    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Date getLastDigTime() {
        return lastDigTime;
    }

    public void setLastDigTime(Date lastDigTime) {
        this.lastDigTime = lastDigTime;
    }

    public Long getRestTime() {
        return restTime;
    }

    public void setRestTime(Long restTime) {
        this.restTime = restTime;
    }

    public Integer getDigTimes() {
        return digTimes;
    }

    public void setDigTimes(Integer digTimes) {
        this.digTimes = digTimes;
    }


    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getCurDigTimes() {
        return curDigTimes;
    }

    public void setCurDigTimes(Integer curDigTimes) {
        this.curDigTimes = curDigTimes;
    }

    public Integer getCurOpenTreasureBoxs() {
        return curOpenTreasureBoxs;
    }

    public void setCurOpenTreasureBoxs(Integer curOpenTreasureBoxs) {
        this.curOpenTreasureBoxs = curOpenTreasureBoxs;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getCash() {
        return cash;
    }

    public void setCash(Long cash) {
        this.cash = cash;
    }

    public Integer getSignDays() {
        return signDays;
    }

    public void setSignDays(Integer signDays) {
        this.signDays = signDays;
    }

    public Date getLastSignTime() {
        return lastSignTime;
    }

    public void setLastSignTime(Date lastSignTime) {
        this.lastSignTime = lastSignTime;
    }

    public Integer getWithdrawTimes() {
        return withdrawTimes;
    }

    public void setWithdrawTimes(Integer withdrawTimes) {
        this.withdrawTimes = withdrawTimes;
    }

    public Integer getCurLayer() {
        return curLayer;
    }

    public void setCurLayer(Integer curLayer) {
        this.curLayer = curLayer;
    }

    public Integer getConditionAmount() {
        return conditionAmount;
    }

    public void setConditionAmount(Integer conditionAmount) {
        this.conditionAmount = conditionAmount;
    }

    public Integer getCurLayerIndex() {
        return curLayerIndex;
    }

    public void setCurLayerIndex(Integer curLayerIndex) {
        this.curLayerIndex = curLayerIndex;
    }

    public Integer getConditionAmountSum() {
        return conditionAmountSum;
    }

    public void setConditionAmountSum(Integer conditionAmountSum) {
        this.conditionAmountSum = conditionAmountSum;
    }

    public List<Integer> getIllustratedHandbookInfo() {
        return illustratedHandbookInfo;
    }

    public void setIllustratedHandbookInfo(List<Integer> illustratedHandbookInfo) {
        this.illustratedHandbookInfo = illustratedHandbookInfo;
    }

    public Integer getBizActivityType() {
        return bizActivityType;
    }

    public void setBizActivityType(Integer bizActivityType) {
        this.bizActivityType = bizActivityType;
    }

    public Integer getStage() {
        return stage;
    }

    public void setStage(Integer stage) {
        this.stage = stage;
    }

    public Integer getStageAmount() {
        return stageAmount;
    }

    public void setStageAmount(Integer stageAmount) {
        this.stageAmount = stageAmount;
    }

    public Long getWithdrawThreshold() {
        return withdrawThreshold;
    }

    public void setWithdrawThreshold(Long withdrawThreshold) {
        this.withdrawThreshold = withdrawThreshold;
    }

    public List<ArrayList<Integer>> getTreasureList() {
        return treasureList;
    }

    public void setTreasureList(List<ArrayList<Integer>> treasureList) {
        this.treasureList = treasureList;
    }

    public List<StageDto> getStages() {
        return stages;
    }

    public void setStages(List<StageDto> stages) {
        this.stages = stages;
    }
}
